# MTF
**Modular Test Framework (MTF)** is a testing framework designed for creating, executing and validating tests. It consists of a set of tools that can be combined to provide the functionality and compatibility needed for various tasks. For this reason, it is called the “MTF Toolchain”.

With compatible hardware modules, such as CMS, BTSRevo, etc., MTF can also be used as a Hardware-In-a-Loop (HIL) System, suited for testing complex embedded systems and devices.
